@@ -2,12 +2,13 @@ from __future__ import annotations
 
 import asyncio
 
-from aiohttp import web
+from aiohttp import ClientTimeout, web
 from graia.amnesia.builtins.aiohttp import AiohttpClientService
 from launart.manager import Launart
 from loguru import logger
 
 from satori.model import Event, LoginStatus, Meta, MetaPayload, Opcode
+from satori.utils import decode
 
 from ..account import Account
 from ..config import WebhookInfo as WebhookInfo
@@ -22,7 +23,7 @@ class WebhookNetwork(BaseNetwork[WebhookInfo]):
 
     @property
     def id(self):
-        return f"satori/network/webhook/{self.config.identity}#{id(self)}"
+        return f"satori/net/wh/{self.config.identity}#{id(self):x}"
 
     async def handle_request(self, req: web.Request):
         header = req.headers
@@ -33,7 +34,7 @@ class WebhookNetwork(BaseNetwork[WebhookInfo]):
         if self.config.token and self.config.token != token:
             return web.Response(status=401)
         op_code = int(header.get("Satori-OpCode", "0"))
-        body = await req.json()
+        body = decode(await req.text())
         if op_code == Opcode.META:
             payload = MetaPayload.parse(body)
             self.proxy_urls = payload.proxy_urls
@@ -63,7 +64,6 @@ class WebhookNetwork(BaseNetwork[WebhookInfo]):
                 logger.trace(f"Failed to parse event: {body}\nCaused by {e!r}")
             return web.Response(status=500, reason=f"Failed to parse event caused by {e!r}")
         else:
-            logger.trace(f"Received event: {event}")
             self.sequence = event.sn
         asyncio.create_task(self.app.post(event, self))
         return web.Response()
@@ -97,6 +97,7 @@ class WebhookNetwork(BaseNetwork[WebhookInfo]):
                 endpoint,
                 json={},
                 headers=headers,
+                timeout=ClientTimeout(total=self.config.timeout or 300),
             ) as resp:
                 data = await validate_response(resp)
                 meta = Meta.parse(data)
@@ -104,7 +105,7 @@ class WebhookNetwork(BaseNetwork[WebhookInfo]):
             for login in meta.logins:
                 if not login.user:
                     continue
-                login_sn = f"{login.user.id}@{id(self)}"
+                login_sn = f"{login.platform}_{login.user.id}@{id(self):x}"
                 account = Account(login, self.config, meta.proxy_urls, self.app.default_api_cls)
                 logger.info(f"account registered: {account}")
                 (account.connected.set() if login.status == LoginStatus.ONLINE else account.connected.clear())
@@ -116,7 +117,7 @@ class WebhookNetwork(BaseNetwork[WebhookInfo]):
             logger.info(f"{self.id} Webhook server exiting...")
             self.close_signal.set()
             for v in list(self.app.accounts.values()):
-                if (identity := f"{v.self_id}@{id(self)}") in self.accounts:
+                if (identity := f"{v.platform}_{v.self_id}@{id(self):x}") in self.accounts:
                     v.connected.clear()
                     await self.app.account_update(v, LoginStatus.OFFLINE)
                     del self.app.accounts[identity]
