@@ -1,23 +1,58 @@
 from base64 import b64encode
-from dataclasses import InitVar, dataclass, field, fields
+from collections.abc import Callable, Sequence
+from dataclasses import InitVar, dataclass, field
 from io import BytesIO
 from pathlib import Path
-from typing import Any, ClassVar, Optional, TypeVar, Union, get_args, overload
+from types import UnionType
+from typing import Any, ClassVar, Final, TypeVar, Union, final, get_args, get_origin, overload
 from typing_extensions import override
 
+from ._vendor.fleep import get
 from .parser import Element as RawElement
-from .parser import escape, param_case
+from .parser import escape, param_case, parse
 from .parser import select as select_raw
+from .utils import decode
 
 TE = TypeVar("TE", bound="Element")
 
 
+def conv_bool(v: str) -> bool:
+    if v.lower() not in ("true", "false"):
+        raise ValueError(v)
+    return v.lower() == "true"
+
+
 @dataclass(repr=False)
 class Element:
     _attrs: dict[str, Any] = field(init=False, default_factory=dict)
     _children: list["Element"] = field(init=False, default_factory=list)
 
     __names__: ClassVar[tuple[str, ...]]
+    __convert_fields__: ClassVar[dict[str, Callable[[str], Any]]]
+
+    def __init_subclass__(cls, **kwargs):
+        cls.__convert_fields__ = {}
+        annotations = cls.__annotations__
+        for name, typ in annotations.items():
+            if name.startswith("_"):
+                continue
+            # _type = get_args(typ)[0] if hasattr(typ, "__origin__") else typ
+            orig = get_origin(typ)
+            if orig in (Union, UnionType):
+                args = get_args(typ)
+                if len(args) == 2 and type(None) in args:
+                    _type = args[0] if args[1] is type(None) else args[1]
+                else:
+                    _type = args[0]
+            else:
+                _type = typ
+            if _type is not str:
+                if _type is bool:
+                    cls.__convert_fields__[name] = conv_bool
+                elif _type in (list, dict):
+                    cls.__convert_fields__[name] = decode
+                else:
+                    cls.__convert_fields__[name] = _type
 
     @property
     def children(self) -> list["Element"]:
@@ -29,24 +64,21 @@ class Element:
 
     @classmethod
     def unpack(cls, attrs: dict[str, Any]):
-        obj = cls(**{k: v for k, v in attrs.items() if k in cls.__names__})  # type: ignore
-        obj._attrs.update({k: v for k, v in attrs.items() if k not in cls.__names__})
+        data = {}
+        names = getattr(cls, "__names__", None)
+        for name in cls.__dataclass_fields__.keys():
+            if name not in attrs:
+                continue
+            if name in cls.__convert_fields__:
+                data[name] = cls.__convert_fields__[name](attrs[name])
+            else:
+                data[name] = attrs[name]
+        obj = cls(**{k: v for k, v in data.items() if names is None or k in names})  # type: ignore
+        obj._attrs.update(data)
         return obj
 
     def __post_init__(self):
-        for f in fields(self):
-            if f.name in ("_attrs", "_children"):
-                continue
-            _type = get_args(f.type)[0] if hasattr(f.type, "__origin__") else f.type
-            if _type is not str and isinstance(attr := getattr(self, f.name), str):
-                if _type is bool:
-                    if attr.lower() not in ("true", "false"):
-                        raise TypeError(f.name, attr)
-                    setattr(self, f.name, attr.lower() == "true")
-                else:
-                    setattr(self, f.name, _type(attr))  # type: ignore
-            self._attrs[f.name] = getattr(self, f.name)
-        self._attrs = {k: v for k, v in self._attrs.items() if v is not None}
+        self._attrs = {k: v for k, v in self.__dict__.items() if not k.startswith("_")}
 
     def attributes(self) -> str:
         def _attr(key: str, value: Any):
@@ -82,7 +114,7 @@ class Element:
             elem += ", { " + ", ".join(repr(i) for i in self._children) + " }"
         return elem + ")"
 
-    def __call__(self, *content: Union[str, "Element"]):
+    def __call__(self, *content: "str | Element"):
         self._children.extend(Text(i) if isinstance(i, str) else i for i in content)
         self.__post_call__()
         return self
@@ -103,22 +135,20 @@ class Text(Element):
     def dumps(self, strip: bool = False) -> str:
         return self.text if strip else escape(self.text)
 
-    __names__ = ("text",)
-
 
 @dataclass(repr=False)
 class At(Element):
     """<at> 元素用于提及某个或某些用户。"""
 
-    id: Optional[str] = None
-    name: Optional[str] = None
-    role: Optional[str] = None
-    type: Optional[str] = None
+    id: str | None = None
+    name: str | None = None
+    role: str | None = None
+    type: str | None = None
 
     @staticmethod
     def role_(
         role: str,
-        name: Optional[str] = None,
+        name: str | None = None,
     ) -> "At":
         return At(role=role, name=name)
 
@@ -126,15 +156,13 @@ class At(Element):
     def all(here: bool = False) -> "At":
         return At(type="here" if here else "all")
 
-    __names__ = ("id", "name", "role", "type")
-
 
 @dataclass(repr=False)
 class Sharp(Element):
     """<sharp> 元素用于提及某个频道。"""
 
     id: str
-    name: Optional[str] = None
+    name: str | None = None
 
 
 @dataclass(repr=False)
@@ -143,8 +171,6 @@ class Link(Element):
 
     href: str
 
-    __names__ = ("href",)
-
     def __post_call__(self):
         if not self._children:
             return
@@ -165,35 +191,41 @@ class Link(Element):
 @dataclass(repr=False)
 class Resource(Element):
     src: str
-    title: Optional[str] = None
-    extra: InitVar[Optional[dict[str, Any]]] = None
-    cache: Optional[bool] = None
-    timeout: Optional[int] = None
+    title: str | None = None
+    extra: InitVar[dict[str, Any] | None] = None
+    cache: bool | None = None
+    timeout: int | None = None
 
     __names__ = ("src", "title")
 
     @classmethod
     def of(
         cls,
-        url: Optional[str] = None,
-        path: Optional[Union[str, Path]] = None,
-        raw: Optional[Union[bytes, BytesIO]] = None,
-        mime: Optional[str] = None,
-        name: Optional[str] = None,
-        duration: Optional[float] = None,
-        poster: Optional[str] = None,
-        extra: Optional[dict[str, Any]] = None,
-        cache: Optional[bool] = None,
-        timeout: Optional[int] = None,
+        url: str | None = None,
+        path: str | Path | None = None,
+        raw: bytes | BytesIO | None = None,
+        mime: str | None = None,
+        name: str | None = None,
+        duration: float | None = None,
+        poster: str | None = None,
+        extra: dict[str, Any] | None = None,
+        cache: bool | None = None,
+        timeout: int | None = None,
         **kwargs,
     ):
-        data: dict[str, Any] = {"extra": extra or kwargs}
+        data: dict[str, Any] = {"extra": extra, **kwargs}
         if url is not None:
             data |= {"src": url}
         elif path:
-            data |= {"src": Path(path).as_uri()}
-        elif raw and mime:
+            data |= {"src": Path(path).resolve().as_uri()}
+        elif raw:
             bd = raw.getvalue() if isinstance(raw, BytesIO) else raw
+            if mime is None:
+                info = get(bd)
+                if info.mimes:
+                    mime = info.mimes[0]
+                else:
+                    raise ValueError("Cannot detect mime type, please specify it")
             data |= {"src": f"data:{mime};base64,{b64encode(bd).decode('utf-8')}"}
         else:
             raise ValueError(f"{cls} need at least one of url, path and raw")
@@ -209,7 +241,7 @@ class Resource(Element):
             data["timeout"] = timeout
         return cls(**data)
 
-    def __post_init__(self, extra: Optional[dict[str, Any]] = None):
+    def __post_init__(self, extra: dict[str, Any] | None = None):
         super().__post_init__()
         if extra:
             self._attrs.update(extra)
@@ -219,8 +251,8 @@ class Resource(Element):
 class Image(Resource):
     """<img> 元素用于表示图片。"""
 
-    width: Optional[int] = None
-    height: Optional[int] = None
+    width: int | None = None
+    height: int | None = None
 
     __names__ = ("src", "title", "width", "height")
 
@@ -234,8 +266,8 @@ class Image(Resource):
 class Audio(Resource):
     """<audio> 元素用于表示语音。"""
 
-    duration: Optional[float] = None
-    poster: Optional[str] = None
+    duration: float | None = None
+    poster: str | None = None
 
     __names__ = ("src", "title", "duration", "poster")
 
@@ -244,10 +276,10 @@ class Audio(Resource):
 class Video(Resource):
     """<video> 元素用于表示视频。"""
 
-    width: Optional[int] = None
-    height: Optional[int] = None
-    duration: Optional[float] = None
-    poster: Optional[str] = None
+    width: int | None = None
+    height: int | None = None
+    duration: float | None = None
+    poster: str | None = None
 
     __names__ = ("src", "title", "width", "height", "duration", "poster")
 
@@ -256,7 +288,7 @@ class Video(Resource):
 class File(Resource):
     """<file> 元素用于表示文件。"""
 
-    poster: Optional[str] = None
+    poster: str | None = None
 
     __names__ = ("src", "title", "poster")
 
@@ -267,7 +299,7 @@ class Style(Element):
 
     __names__ = ()
 
-    def __init__(self, *text: Union[str, Text, "Style"]):
+    def __init__(self, *text: "str | Text | Style"):
         super().__init__()
         self.__call__(*text)
 
@@ -374,16 +406,14 @@ class Message(Element):
     子元素对应于消息的内容。如果其没有子元素，则消息不会被发送。
     """
 
-    __names__ = ("id", "forward")
-
-    id: Optional[str]
-    forward: Optional[bool]
+    id: str | None
+    forward: bool | None
 
     def __init__(
         self,
-        id: Optional[str] = None,
-        forward: Optional[bool] = None,
-        content: Optional[list[Union[str, Element]]] = None,
+        id: str | None = None,
+        forward: bool | None = None,
+        content: list[str | Element] | None = None,
     ):
         self.id = id
         self.forward = forward
@@ -405,10 +435,8 @@ class Author(Element):
     """<author> 元素用于表示消息的作者。它的子元素会被渲染为作者的名字。"""
 
     id: str
-    name: Optional[str] = None
-    avatar: Optional[str] = None
-
-    __names__ = ("id", "name", "avatar")
+    name: str | None = None
+    avatar: str | None = None
 
 
 @dataclass(repr=False)
@@ -416,23 +444,21 @@ class Button(Element):
     """<button> 元素用于表示一个按钮。它的子元素会被渲染为按钮的文本。"""
 
     type: str
-    id: Optional[str] = None
-    href: Optional[str] = None
-    text: Optional[str] = None
-    theme: Optional[str] = None
-
-    __names__ = ("type", "id", "href", "text", "theme")
+    id: str | None = None
+    href: str | None = None
+    text: str | None = None
+    theme: str | None = None
 
     @classmethod
-    def action(cls, button_id: str, theme: Optional[str] = None):
+    def action(cls, button_id: str, theme: str | None = None):
         return Button("action", id=button_id, theme=theme)
 
     @classmethod
-    def link(cls, url: str, theme: Optional[str] = None):
+    def link(cls, url: str, theme: str | None = None):
         return Button("link", href=url, theme=theme)
 
     @classmethod
-    def input(cls, text: str, theme: Optional[str] = None):
+    def input(cls, text: str, theme: str | None = None):
         return Button("input", text=text, theme=theme)
 
     def attributes(self) -> str:
@@ -460,18 +486,15 @@ class Button(Element):
 class Custom(Element):
     """自定义元素用于构造标准元素以外的元素"""
 
-    type: str
-
     __names__ = ()
 
     def __init__(
         self,
         type: str,
-        attrs: Optional[dict[str, Any]] = None,
-        children: Optional[list[Union[str, Element]]] = None,
+        attrs: dict[str, Any] | None = None,
+        children: Sequence[str | Element] | None = None,
     ):
         self.type = type
-        super().__init__()
         if not hasattr(self, "_attrs"):
             self._attrs = attrs or {}
         else:
@@ -500,6 +523,17 @@ class Raw(Element):
         return self.content if strip else escape(self.content)
 
 
+def register_element(cls: type[TE], tag: str | None = None) -> type[TE]:
+    """注册一个自定义元素类，使其可以被 `transform` 函数识别。
+
+    该类必须继承自 `Element`; 必要时还需要定义 `__names__` 类变量以指定可接受的属性名。
+    """
+    if not issubclass(cls, Element):
+        raise TypeError("cls must be a subclass of Element")
+    ELEMENT_TYPE_MAP[tag or cls.__name__.lower()] = cls
+    return cls
+
+
 ELEMENT_TYPE_MAP = {
     "text": Text,
     "at": At,
@@ -571,14 +605,14 @@ def transform(elements: list[RawElement]) -> list[Element]:
 
 
 @overload
-def select(elements: Union[Element, list[Element]], query: type[TE]) -> list[TE]: ...
+def select(elements: Element | list[Element], query: type[TE]) -> list[TE]: ...
 
 
 @overload
-def select(elements: Union[Element, list[Element]], query: str) -> list[Element]: ...
+def select(elements: Element | list[Element], query: str) -> list[Element]: ...
 
 
-def select(elements: Union[Element, list[Element]], query: Union[type[TE], str]):
+def select(elements: Element | list[Element], query: type[TE] | str):
     if not elements:
         return []
     if isinstance(elements, Element):
@@ -596,39 +630,44 @@ def select(elements: Union[Element, list[Element]], query: Union[type[TE], str])
     return results
 
 
-class E:
-    text = Text
-    at = At
-    at_role = At.role_
-    at_all = At.all
-    sharp = Sharp
-    link = Link
-    image = Image.of
-    audio = Audio.of
-    video = Video.of
-    file = File.of
-    resource = Resource
-    bold = Bold
-    italic = Italic
-    underline = Underline
-    strikethrough = Strikethrough
-    spoiler = Spoiler
-    code = Code
-    sup = Superscript
-    sub = Subscript
-    br = Br
-    paragraph = Paragraph
-    message = Message
-    quote = Quote
-    author = Author
-    custom = Custom
-    raw = Raw
-    button = Button
-    action_button = Button.action
-    link_button = Button.link
-    input_button = Button.input
+@final
+class _E:
+    def __init__(self):
+        self.text = Text
+        self.at = At
+        self.at_role = At.role_
+        self.at_all = At.all
+        self.sharp = Sharp
+        self.link = Link
+        self.image = Image.of
+        self.audio = Audio.of
+        self.video = Video.of
+        self.file = File.of
+        self.resource = Resource
+        self.bold = Bold
+        self.italic = Italic
+        self.underline = Underline
+        self.strikethrough = Strikethrough
+        self.spoiler = Spoiler
+        self.code = Code
+        self.sup = Superscript
+        self.sub = Subscript
+        self.br = Br
+        self.paragraph = Paragraph
+        self.message = Message
+        self.quote = Quote
+        self.author = Author
+        self.raw = Raw
+        self.button = Button
+        self.action_button = Button.action
+        self.link_button = Button.link
+        self.input_button = Button.input
+        self.select = select
 
-    select = select
+    def __call__(self, elem: str, context: dict | None = None) -> Custom:
+        """创建一个自定义元素"""
+        e = parse(elem, context)[0]
+        return Custom(e.type, e.attrs, transform(e.children))
 
-    def __new__(cls, *args, **kwargs):
-        raise TypeError("E is not instantiable")
+
+E: Final = _E()
