@@ -1,6 +1,6 @@
-from collections.abc import Awaitable
-from typing import Any, Callable, Literal, Protocol, TypeVar, Union, overload
-from typing_extensions import NotRequired, TypeAlias, TypedDict
+from collections.abc import Awaitable, Callable
+from typing import Any, Literal, Protocol, TypeAlias, TypeVar, overload
+from typing_extensions import NotRequired, TypedDict
 
 from starlette.datastructures import FormData
 
@@ -30,17 +30,16 @@ class RouteCall(Protocol[T, R]):
     def __call__(self, request: Request[T]) -> Awaitable[R]: ...
 
 
-INTERAL: TypeAlias = RouteCall[
-    Any, Union[ModelBase, list[ModelBase], dict[str, Any], list[dict[str, Any]], None]
-]
+INTERAL: TypeAlias = RouteCall[Any, ModelBase | list[ModelBase] | dict[str, Any] | list[dict[str, Any]] | None]
 
 
 class MessageParam(TypedDict):
     channel_id: str
     content: str
+    referrer: NotRequired[dict[str, Any]]
 
 
-MESSAGE_CREATE: TypeAlias = RouteCall[MessageParam, Union[list[MessageObject], list[dict[str, Any]]]]
+MESSAGE_CREATE: TypeAlias = RouteCall[MessageParam, list[MessageObject] | list[dict[str, Any]]]
 
 
 class MessageOpParam(TypedDict):
@@ -48,7 +47,7 @@ class MessageOpParam(TypedDict):
     message_id: str
 
 
-MESSAGE_GET: TypeAlias = RouteCall[MessageOpParam, Union[MessageObject, dict[str, Any]]]
+MESSAGE_GET: TypeAlias = RouteCall[MessageOpParam, MessageObject | dict[str, Any]]
 MESSAGE_DELETE: TypeAlias = RouteCall[MessageOpParam, None]
 
 
@@ -69,14 +68,14 @@ class MessageListParam(TypedDict):
     order: NotRequired[Order]
 
 
-MESSAGE_LIST: TypeAlias = RouteCall[MessageListParam, Union[PageDequeResult[MessageObject], dict[str, Any]]]
+MESSAGE_LIST: TypeAlias = RouteCall[MessageListParam, PageDequeResult[MessageObject] | dict[str, Any]]
 
 
 class ChannelParam(TypedDict):
     channel_id: str
 
 
-CHANNEL_GET: TypeAlias = RouteCall[ChannelParam, Union[Channel, dict[str, Any]]]
+CHANNEL_GET: TypeAlias = RouteCall[ChannelParam, Channel | dict[str, Any]]
 CHANNEL_DELETE: TypeAlias = RouteCall[ChannelParam, None]
 
 
@@ -85,23 +84,23 @@ class ChannelListParam(TypedDict):
     next: NotRequired[str]
 
 
-CHANNEL_LIST: TypeAlias = RouteCall[ChannelListParam, Union[PageResult[Channel], dict[str, Any]]]
+CHANNEL_LIST: TypeAlias = RouteCall[ChannelListParam, PageResult[Channel] | dict[str, Any]]
 
 
-class ChanneCreateParam(TypedDict):
+class ChannelCreateParam(TypedDict):
     guild_id: str
     data: dict
 
 
-CHANNEL_CREATE: TypeAlias = RouteCall[ChanneCreateParam, Union[Channel, dict[str, Any]]]
+CHANNEL_CREATE: TypeAlias = RouteCall[ChannelCreateParam, Channel | dict[str, Any]]
 
 
-class ChanneUpdateParam(TypedDict):
+class ChannelUpdateParam(TypedDict):
     channel_id: str
     data: dict
 
 
-CHANNEL_UPDATE: TypeAlias = RouteCall[ChanneUpdateParam, None]
+CHANNEL_UPDATE: TypeAlias = RouteCall[ChannelUpdateParam, None]
 
 
 class ChannelMuteParam(TypedDict):
@@ -117,21 +116,21 @@ class UserChannelCreateParam(TypedDict):
     guild_id: NotRequired[str]
 
 
-ROUTE_USER_CHANNEL_CREATE: TypeAlias = RouteCall[UserChannelCreateParam, Union[Channel, dict[str, Any]]]
+ROUTE_USER_CHANNEL_CREATE: TypeAlias = RouteCall[UserChannelCreateParam, Channel | dict[str, Any]]
 
 
 class GuildGetParam(TypedDict):
     guild_id: str
 
 
-GUILD_GET: TypeAlias = RouteCall[GuildGetParam, Union[Guild, dict[str, Any]]]
+GUILD_GET: TypeAlias = RouteCall[GuildGetParam, Guild | dict[str, Any]]
 
 
 class GuildListParam(TypedDict):
     next: NotRequired[str]
 
 
-GUILD_LIST: TypeAlias = RouteCall[GuildListParam, Union[PageResult[Guild], dict[str, Any]]]
+GUILD_LIST: TypeAlias = RouteCall[GuildListParam, PageResult[Guild] | dict[str, Any]]
 
 
 class GuildMemberGetParam(TypedDict):
@@ -139,7 +138,7 @@ class GuildMemberGetParam(TypedDict):
     user_id: str
 
 
-GUILD_MEMBER_GET: TypeAlias = RouteCall[GuildMemberGetParam, Union[Member, dict[str, Any]]]
+GUILD_MEMBER_GET: TypeAlias = RouteCall[GuildMemberGetParam, Member | dict[str, Any]]
 
 
 class GuildXXXListParam(TypedDict):
@@ -147,7 +146,7 @@ class GuildXXXListParam(TypedDict):
     next: NotRequired[str]
 
 
-GUILD_MEMBER_LIST: TypeAlias = RouteCall[GuildXXXListParam, Union[PageResult[Member], dict[str, Any]]]
+GUILD_MEMBER_LIST: TypeAlias = RouteCall[GuildXXXListParam, PageResult[Member] | dict[str, Any]]
 
 
 class GuildMemberKickParam(TypedDict):
@@ -177,19 +176,19 @@ class GuildMemberRoleParam(TypedDict):
 GUILD_MEMBER_ROLE_SET: TypeAlias = RouteCall[GuildMemberRoleParam, None]
 GUILD_MEMBER_ROLE_UNSET: TypeAlias = RouteCall[GuildMemberRoleParam, None]
 
-GUILD_ROLE_LIST: TypeAlias = RouteCall[GuildXXXListParam, Union[PageResult[Role], dict[str, Any]]]
+GUILD_ROLE_LIST: TypeAlias = RouteCall[GuildXXXListParam, PageResult[Role] | dict[str, Any]]
 
 
 class GuildRoleCreateParam(TypedDict):
-    guild: str
+    guild_id: str
     role: dict
 
 
-GUILD_ROLE_CREATE: TypeAlias = RouteCall[GuildRoleCreateParam, Union[Role, dict[str, Any]]]
+GUILD_ROLE_CREATE: TypeAlias = RouteCall[GuildRoleCreateParam, Role | dict[str, Any]]
 
 
 class GuildRoleUpdateParam(TypedDict):
-    guild: str
+    guild_id: str
     role_id: str
     role: dict
 
@@ -198,7 +197,7 @@ GUILD_ROLE_UPDATE: TypeAlias = RouteCall[GuildRoleUpdateParam, None]
 
 
 class GuildRoleDeleteParam(TypedDict):
-    guild: str
+    guild_id: str
     role_id: str
 
 
@@ -240,28 +239,28 @@ class ReactionListParam(TypedDict):
     next: NotRequired[str]
 
 
-REACTION_LIST: TypeAlias = RouteCall[ReactionListParam, Union[PageResult[User], dict[str, Any]]]
-LOGIN_GET: TypeAlias = RouteCall[Any, Union[Login, dict[str, Any]]]
+REACTION_LIST: TypeAlias = RouteCall[ReactionListParam, PageResult[User] | dict[str, Any]]
+LOGIN_GET: TypeAlias = RouteCall[Any, Login | dict[str, Any]]
 
 
 class UserGetParam(TypedDict):
     user_id: str
 
 
-USER_GET: TypeAlias = RouteCall[UserGetParam, Union[User, dict[str, Any]]]
+USER_GET: TypeAlias = RouteCall[UserGetParam, User | dict[str, Any]]
 
 
 class FriendListParam(TypedDict):
     next: NotRequired[str]
 
 
-FRIEND_LIST: TypeAlias = RouteCall[FriendListParam, Union[PageResult[User], dict[str, Any]]]
+FRIEND_LIST: TypeAlias = RouteCall[FriendListParam, PageResult[User] | dict[str, Any]]
 
 
 class ApproveParam(TypedDict):
     message_id: str
     approve: bool
-    comment: str
+    comment: NotRequired[str]
 
 
 APPROVE: TypeAlias = RouteCall[ApproveParam, None]
@@ -321,24 +320,16 @@ class RouterMixin:
     def route(self, path: Literal[Api.GUILD_APPROVE]) -> Callable[[APPROVE], APPROVE]: ...
 
     @overload
-    def route(
-        self, path: Literal[Api.GUILD_MEMBER_LIST]
-    ) -> Callable[[GUILD_MEMBER_LIST], GUILD_MEMBER_LIST]: ...
+    def route(self, path: Literal[Api.GUILD_MEMBER_LIST]) -> Callable[[GUILD_MEMBER_LIST], GUILD_MEMBER_LIST]: ...
 
     @overload
-    def route(
-        self, path: Literal[Api.GUILD_MEMBER_GET]
-    ) -> Callable[[GUILD_MEMBER_GET], GUILD_MEMBER_GET]: ...
+    def route(self, path: Literal[Api.GUILD_MEMBER_GET]) -> Callable[[GUILD_MEMBER_GET], GUILD_MEMBER_GET]: ...
 
     @overload
-    def route(
-        self, path: Literal[Api.GUILD_MEMBER_KICK]
-    ) -> Callable[[GUILD_MEMBER_KICK], GUILD_MEMBER_KICK]: ...
+    def route(self, path: Literal[Api.GUILD_MEMBER_KICK]) -> Callable[[GUILD_MEMBER_KICK], GUILD_MEMBER_KICK]: ...
 
     @overload
-    def route(
-        self, path: Literal[Api.GUILD_MEMBER_MUTE]
-    ) -> Callable[[GUILD_MEMBER_MUTE], GUILD_MEMBER_MUTE]: ...
+    def route(self, path: Literal[Api.GUILD_MEMBER_MUTE]) -> Callable[[GUILD_MEMBER_MUTE], GUILD_MEMBER_MUTE]: ...
 
     @overload
     def route(self, path: Literal[Api.GUILD_MEMBER_APPROVE]) -> Callable[[APPROVE], APPROVE]: ...
@@ -357,19 +348,13 @@ class RouterMixin:
     def route(self, path: Literal[Api.GUILD_ROLE_LIST]) -> Callable[[GUILD_ROLE_LIST], GUILD_ROLE_LIST]: ...
 
     @overload
-    def route(
-        self, path: Literal[Api.GUILD_ROLE_CREATE]
-    ) -> Callable[[GUILD_ROLE_CREATE], GUILD_ROLE_CREATE]: ...
+    def route(self, path: Literal[Api.GUILD_ROLE_CREATE]) -> Callable[[GUILD_ROLE_CREATE], GUILD_ROLE_CREATE]: ...
 
     @overload
-    def route(
-        self, path: Literal[Api.GUILD_ROLE_UPDATE]
-    ) -> Callable[[GUILD_ROLE_UPDATE], GUILD_ROLE_UPDATE]: ...
+    def route(self, path: Literal[Api.GUILD_ROLE_UPDATE]) -> Callable[[GUILD_ROLE_UPDATE], GUILD_ROLE_UPDATE]: ...
 
     @overload
-    def route(
-        self, path: Literal[Api.GUILD_ROLE_DELETE]
-    ) -> Callable[[GUILD_ROLE_DELETE], GUILD_ROLE_DELETE]: ...
+    def route(self, path: Literal[Api.GUILD_ROLE_DELETE]) -> Callable[[GUILD_ROLE_DELETE], GUILD_ROLE_DELETE]: ...
 
     @overload
     def route(self, path: Literal[Api.REACTION_CREATE]) -> Callable[[REACTION_CREATE], REACTION_CREATE]: ...
@@ -401,8 +386,8 @@ class RouterMixin:
     @overload
     def route(self, path: str) -> Callable[[INTERAL], INTERAL]: ...
 
-    def route(self, path: Union[str, Api]) -> Callable[[RouteCall], RouteCall]:
-        """注册一个路由
+    def route(self, path: str | Api) -> Callable[[RouteCall], RouteCall]:
+        """注册一个 Satori 路由
 
         Args:
             path (str | Api): 路由路径；若 path 不属于 Api，则会被认为是内部接口
